==> quwen-fun-center-api-0.0.4_wsz19-20180912.082234-2-sources.jar: rsp/HotArticleSetRsp.java <==
package rsp;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by wsz on 2018/9/7 11:27.
 */
public class HotArticleSetRsp implements Serializable {
    private Long hotAriticleId;
    private String title;
    private String author;
    private Date editTime;
    private String imgUrl;

    private String titleContent;
    private String buttonContent;
    private String articleUrl;

    private Integer boxFlag;
    private Integer boxMultiple;
    private Long coinReward;

    public Long getCoinReward() {
        return coinReward;
    }

    public void setCoinReward(Long coinReward) {
        this.coinReward = coinReward;
    }

    public Long getHotAriticleId() {
        return hotAriticleId;
    }

    public void setHotAriticleId(Long hotAriticleId) {
        this.hotAriticleId = hotAriticleId;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public Integer getBoxFlag() {
        return boxFlag;
    }

    public void setBoxFlag(Integer boxFlag) {
        this.boxFlag = boxFlag;
    }

    public Integer getBoxMultiple() {
        return boxMultiple;
    }

    public void setBoxMultiple(Integer boxMultiple) {
        this.boxMultiple = boxMultiple;
    }

    public Date getEditTime() {
        return editTime;
    }

    public void setEditTime(Date editTime) {
        this.editTime = editTime;
    }

    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTitleContent() {
        return titleContent;
    }

    public void setTitleContent(String titleContent) {
        this.titleContent = titleContent;
    }

    public String getButtonContent() {
        return buttonContent;
    }

    public void setButtonContent(String buttonContent) {
        this.buttonContent = buttonContent;
    }

    public String getArticleUrl() {
        return articleUrl;
    }

    public void setArticleUrl(String articleUrl) {
        this.articleUrl = articleUrl;
    }

}

==> quwen-fun-center-api-0.0.7_wsz07-20181015.065229-1-sources.jar: rsp/HotArticleSetRsp.java <==
package rsp;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by wsz on 2018/9/7 11:27.
 */
public class HotArticleSetRsp extends BaseActivitySetRsp {
    private Long hotAriticleId;
    private String title;
    private String author;
    private Date editTime;
    private String imgUrl;

    private String titleContent;
    private String buttonContent;
    private String articleUrl;

    private Integer boxFlag;
    private Integer boxMultiple;
    private Long coinReward;

    public Long getCoinReward() {
        return coinReward;
    }

    public void setCoinReward(Long coinReward) {
        this.coinReward = coinReward;
    }

    public Long getHotAriticleId() {
        return hotAriticleId;
    }

    public void setHotAriticleId(Long hotAriticleId) {
        this.hotAriticleId = hotAriticleId;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public Integer getBoxFlag() {
        return boxFlag;
    }

    public void setBoxFlag(Integer boxFlag) {
        this.boxFlag = boxFlag;
    }

    public Integer getBoxMultiple() {
        return boxMultiple;
    }

    public void setBoxMultiple(Integer boxMultiple) {
        this.boxMultiple = boxMultiple;
    }

    public Date getEditTime() {
        return editTime;
    }

    public void setEditTime(Date editTime) {
        this.editTime = editTime;
    }

    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTitleContent() {
        return titleContent;
    }

    public void setTitleContent(String titleContent) {
        this.titleContent = titleContent;
    }

    public String getButtonContent() {
        return buttonContent;
    }

    public void setButtonContent(String buttonContent) {
        this.buttonContent = buttonContent;
    }

    public String getArticleUrl() {
        return articleUrl;
    }

    public void setArticleUrl(String articleUrl) {
        this.articleUrl = articleUrl;
    }

}
